Learn R Programming

msmsTests (version 1.10.0)

msms.glm.qlll: Spectral counts differential expression by quasi-likelihood GLM

Description

Given a null and an alternative model, with a two level treatment factor as the two conditions to compare, executes a quasi-likelihood based GLM regression to discover differentially expressed proteins between the two conditions. The null and alternative models may include blocking factors.The reference level of the main factor is considered to be the control condition.

Usage

msms.glm.qlll(msnset,form1,form0,facs=NULL,div=NULL)

Arguments

msnset
A MSnSet object with spectral counts in the expression matrix.
form1
The alternative hypothesis model as an standard R formula, with the treatment factor of interest, and eventual blocking factors.
form0
The null hypothesis model as an standard R formula.It may be the standard null model (y~.) or contain one or multiple blocking factors.
facs
NULL or a data frame with the factors in its columns.
div
NULL or a vector with the divisors used to compute the offsets.

Value

A data frame with the following columns:
LogFC
Log fold change estimated from the model parameters.
D
Residual deviance as statistic of the test.
p.value
The p-values obtained from the test.

Details

The right hand site of the formulas is expected to be "y~", with the combination of factors after the tilde. If facs is NULL the factors are taken as default from pData(msnset). If div is NULL all divisors are taken equal to one.

References

Agresti, A. (2002) Categorical Data Analysis, 2nd Edition, John Wiley & Sons, Inc., Hoboken, New Jersey

Thompson L.A. (2009) R (and S-PLUS) Manual to Accompany Agresti s Categorical Data Analysis, 2nd edition https://home.comcast.net/~lthompson221/Splusdiscrete2.pdf

Dobson, A.J. (2002) An Introduction to Generalized Linear Models, 2nd Edition, Chapman & Hall/CRC, New York

Venables, W. N. and Ripley, B. D. (2002) Modern Applied Statistics with S, New York: Springer

Li, M.; Gray, W.; Zhang, H.; Chung, C. H.; Billheimer, D.; Yarbrough, W. G.; Liebler, D. C.; Shyr, Y.; Slebos, R. J. C. Comparative shotgun proteomics using spectral count data and quasi-likelihood modeling, J Proteome Res 2010, 9, 4295-4305.

Josep Gregori, Laura Villareal, Alex Sanchez, Jose Baselga, Josep Villanueva (2013). An Effect Size Filter Improves the Reproducibility in Spectral Counting-based Comparative Proteomics, Journal of Proteomics, http://dx.doi.org/10.1016/j.jprot.2013.05.030

See Also

MSnSet, glm

Examples

Run this code
library(msmsTests)
data(msms.dataset)
# Pre-process expression matrix
e <- pp.msms.data(msms.dataset)
# Factors
pData(e)
# Control condition
levels(pData(e)$treat)[1]
# Treatment condition
levels(pData(e)$treat)[2]

# Models and normalizing condition
null.f <- "y~batch"
alt.f <- "y~treat+batch"
div <- apply(exprs(e),2,sum)

#Test
res <- msms.glm.qlll(e,alt.f,null.f,div=div)

str(res)
head(res)

Run the code above in your browser using DataLab